"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildTask = void 0;

var _path = require("path");

var _packageLoad = require("../actions/npm/packageLoad");

var _packageWorkspaces = require("../actions/npm/packageWorkspaces");

var _babel = require("../actions/tools/babel");

var _tsc = require("../actions/tools/tsc");

var _spinner = require("../cli/spinner");

var _hasDependency = require("../utils/hasDependency");

var _taskHook = require("../utils/taskHook");

const buildTask = async argv => {
  await (0, _taskHook.taskHook)(argv, {
    task: 'build',
    type: 'pre'
  });
  const workspacePaths = await (0, _packageWorkspaces.npmPackageWorkspacesAction)(argv);
  const hasTypescript = await (0, _hasDependency.hasDependency)(argv, {
    dependency: 'typescript',
    dependencyType: 'devDependencies'
  });
  const paths = workspacePaths.length > 0 ? workspacePaths : [argv.cwd];

  if (hasTypescript) {
    await paths.reduce((promise, path) => promise.then(async () => {
      const isPrivate = await (0, _packageLoad.npmPackageLoadAction)(argv, {
        key: 'private',
        path
      });
      const subTitle = path === argv.cwd ? '' : `[${(0, _path.basename)(path)}]`;

      if (isPrivate === true) {
        return Promise.resolve();
      }

      return (0, _spinner.spinnerAction)((0, _tsc.tscAction)({ ...argv,
        cwd: path
      }, {
        mode: 'type-create'
      }), `Build: Typescript ${subTitle}`);
    }), Promise.resolve());
  }

  await paths.reduce((promise, path) => promise.then(async () => {
    const subTitle = path === argv.cwd ? '' : `[${(0, _path.basename)(path)}]`;
    return (0, _spinner.spinnerAction)((0, _babel.babelAction)({ ...argv,
      cwd: path
    }), `Build: Babel ${subTitle}`);
  }), Promise.resolve());
  await (0, _taskHook.taskHook)(argv, {
    task: 'build',
    type: 'post'
  });
};

exports.buildTask = buildTask;